==> deepin-voice-recorder_1.3.6.1.orig.tar.gz: deepin-voice-recorder-1.3.6.1/translations/deepin-voice-recorder_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>Mover para o lixo</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Nova gravação</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Abrir no diretório de gravação</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>O Gravador de voz Deepin é um fácil e bonito gravador de voz. Este, tem funções como gravação, reprodução de gravações, gestor de gravações e outras funções</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Gravador de Voz Deepin</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Gravador de Voz Deepin</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Nova gravação</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>A gravar</translation>
    </message>
</context>
</TS>

==> deepin-voice-recorder_1.3.9.orig.tar.gz: deepin-voice-recorder-1.3.9/translations/deepin-voice-recorder_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>Mover para o lixo</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Nova gravação</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Abrir no diretório de gravação</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>O Deepin Voice Recorder é um fácil e bonito gravador de voz. Este, tem funções como gravação, reprodução de gravações, gestor de gravações e outras funções.</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Voice Recorder</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Voice Recorder</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Nova gravação</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>A gravar</translation>
    </message>
</context>
</TS>
